@@ -1,5 +1,4 @@
 import os
-import threading
 import subprocess
 import paramiko
 from log import log
@@ -48,7 +47,8 @@ class SSHClient(object):
         except:
             pass
 
-    def _exec(self, cmd, promt_response, results):
+    @func_set_timeout(int(os.environ.get("SSH_COMMAND_TIMEOUT", 60)))
+    def _exec(self, cmd, promt_response):
         log.info(f" {self.__ip}:{self.__port} | begin to run cmd:{cmd}.")
         try:
             if promt_response:
@@ -80,37 +80,21 @@ class SSHClient(object):
                 std_err = stderr.read().decode()
                 log.info(
                     f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, output is:{std_output}.")
-                results.append(ExecResult(exit_status, std_output, std_err))
                 return ExecResult(exit_status, std_output, std_err)
         except Exception as e:
-            results.append(ExecResult(255, "", str(e)))
             return ExecResult(255, "", str(e))
 
     def exec(self, cmd, promt_response=[], timeout=60):
         try:
+            os.environ["SSH_COMMAND_TIMEOUT"] = str(timeout)
             if not self.is_active():
                 raise RuntimeError("ssh transport is not active.")
-            results = []
-            t = threading.Thread(target=self._exec, args=(cmd, promt_response, results))
-            t.start()
-            t.join(timeout=timeout)
-            if t.is_alive():
-                log.error(
-                    f"{self.__ip}:{self.__port}: {timeout} has passed but thread is still alive.kill and return None.")
-                raise RuntimeError("{timeout} has passed but thread is still alive.kill and return None.")
-            else:
-                return results[0]
-        except RuntimeError() as e:
-            log.error(f"{self.__ip}:{self.__port} | ssh transport is not active:Error.")
-            return ExecResult(255, "", str(e))
-        except TimeoutError as e1:
-            log.error(f"{self.__ip}:{self.__port} | timeout to run cmd:{cmd}.", exc_info=True)
-            return ExecResult(255, "", str(e1))
-        except Exception as e2:
+            return self._exec(cmd,promt_response)
+        except Exception as e:
             log.error(f"when run cmd: {cmd}, meets exception.", exc_info=True)
-            return ExecResult(255, "", str(e2))
+            return ExecResult(255, "", str(e))
 
-    @func_set_timeout(120)
+    @func_set_timeout(int(os.environ.get("SSH_SCP_TO_REMOTE_TIMEOUT", 120)))
     def _scp_to_remote(self, local_path, remote_path):
         log.info(
             f" {self.__ip}:{self.__port} | Begin to copy file from local {local_path} to remote host {remote_path}.")
@@ -125,10 +109,11 @@ class SSHClient(object):
                 f" {self.__ip}:{self.__port} | failed to copy file from local {local_path} to remote host{remote_path}:Error.")
             return False
 
-    def scp_to_remote(self, local_path, remote_path):
+    def scp_to_remote(self, local_path, remote_path,timeout=120):
         try:
             if not self.is_active():
                 raise RuntimeError("ssh transport is not active.")
+            os.environ["SSH_SCP_TO_REMOTE_TIMEOUT"] = str(timeout)
             return self._scp_to_remote(local_path, remote_path)
         except RuntimeError:
             log.error(
@@ -144,7 +129,7 @@ class SSHClient(object):
             log.error(f"when scp from local {local_path} to remote {remote_path}, meets exception.", exc_info=True)
             return False
 
-    @func_set_timeout(120)
+    @func_set_timeout(int(os.environ.get("SSH_SCP_FILE_TO_LOCAL_TIMEOUT",120)))
     def _scp_file_to_local(self, remote_path, local_path):
         log.info(
             f" {self.__ip}:{self.__port} | Begin to copy file from remote {remote_path} to local host {local_path}.")
@@ -161,10 +146,11 @@ class SSHClient(object):
                 f" {self.__ip}:{self.__port} | failed to copy file from remote {remote_path} to local host{local_path}:Error.")
             return False
 
-    def scp_file_to_local(self, remote_path, local_path):
+    def scp_file_to_local(self, remote_path, local_path,timeout=120):
         try:
             if not self.is_active():
                 raise RuntimeError("ssh transport is not active.")
+            os.environ["SSH_SCP_FILE_TO_LOCAL_TIMEOUT"] = str(timeout)
             return self._scp_file_to_local(remote_path, local_path)
         except RuntimeError:
             log.error(
